@@ -4,15 +4,15 @@ qr code displayer widget
 
 The popup widget :class:`QrDisplayerPopup` provided by this ae namespace portion is displaying QR codes.
 
-The :class:`QrDisplayerPopup` is inherited from :class:`ae.kivy_app.FlowPopup` and is embedding the
-Kivy Garden :mod:`kivy_garden.qrcode` module.
+The :class:`QrDisplayerPopup` is inherited from :class:`ae.kivy_app.FlowPopup` and is embedding the Kivy Garden
+:mod:`kivy_garden.qrcode` module.
 
 qr displayer popup usage
 ------------------------
 
-To display a QR code instantiate :class:`QrDisplayerPopup` specifying in the `title` property of the popup the
-string to encode to a QR image and in the `qr_content` property a short string describing the content of the string
-to encode. After that call the `open` method::
+To display a QR code instantiate :class:`QrDisplayerPopup` specifying in the `title` property of the popup the string to
+encode to a QR image and in the `qr_content` property a short string describing the content of the string to encode.
+After that call the `open` method::
 
     qr_displayer = QrDisplayerPopup(title="string to encode", qr_content="what to encode")
     qr_displayer.open()
@@ -31,8 +31,13 @@ translation texts provided in the resources of this ae namespace portion.
     If your app is providing i18n translations then the `qr_content` string has to be translated (e.g. by using
     :meth:`~ae.kivy_app.get_txt` or :meth:`~ae.i18n.get_text`) before it gets passed to the popup kwargs.
 
-To support additional languages simply add the translations texts to your app's translation texts resources or
-submit a PR to add them to this ae namespace portion.
+To support additional languages simply add the translations texts to your app's translation texts resources or submit a
+PR to add them to this ae namespace portion. Alternatively you could put different wording by specifying also the
+english translation text.
+
+.. hint::
+    Apart from `root.qr_content` you can also use `root.title` in the translation texts to repeat/mention the string to
+    encode in the text content.
 """
 from kivy.lang import Builder                       # type: ignore
 from kivy.properties import StringProperty          # type: ignore # pylint: disable=no-name-in-module
@@ -44,7 +49,7 @@ from ae.i18n import register_package_translations   # type: ignore
 from ae.kivy_app import FlowPopup                   # type: ignore
 
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 
 register_package_translations()
@@ -52,22 +57,27 @@ register_package_translations()
 Builder.load_string('''\
 <QrDisplayerPopup>
     title: "string to codify"
-    BoxLayout:
-        orientation: 'vertical'
-        spacing: '18sp'
-        padding: '18sp'
-        ImageLabel:
-            text:
-                # duplicate backslash (in \\n) prevents Kivy rule parsing exception
-                _("The {root.qr_content} shown in the window title is underneath encoded as QR code.") \
-                + _("\\nEither manually type/copy the window title string or use a QR code reader.") \
-                + _("\\n\\nTap outside of this window to close it.")
-            text_size: root.width - self.parent.padding[0] - self.parent.padding[2], None
-            size_hint_y: None
-            height: self.texture_size[1]
-        QRCodeWidget:
-            data: root.title
-            show_border: False      # QRCodeWidget border bug (if root window pos of QR image is not at 0, 0); issue #13
+    query_data_maps:
+        [dict(cls='QRCodeWidget', kwargs=dict(
+        data=root.title,
+        size_hint=(1, 1),
+        size_hint_min=(sp(300), sp(300)),
+        size_hint_max=(sp(600), sp(600)),
+        ))]
+    optimal_content_width: root._max_width / (2.1 if app.landscape else 0.99)
+    optimal_content_height: max(c_text.height, root.ids.query_box.height) if app.landscape else c_text.height
+    ImageLabel:
+        id: c_text
+        markup: True
+        text:
+            # duplicate backslash (in \\n) prevents Kivy rule parsing exception
+            _("The displayed QR code contains the [b]{root.qr_content}[/b] shown in the window title.") \
+            + _("\\nEither copy manually the window title string or use a QR code reader.") \
+            + _("\\n\\nTap outside of this window to close it.")
+        text_size: root.optimal_content_width - self.padding_x * 2.1, None
+        size_hint_y: None
+        height: self.texture_size[1]
+        padding: sp(18), sp(9)
 ''')
 
 
